SELECT
"Date",
"Year",
"QuarterNumber",
CONCAT("QuarterNumber", '/Q') as "Quarter",
"Year" * 10 + "QuarterNumber" AS "YearQuarterNumber",
CONCAT("Year", '-Q', "QuarterNumber") as "YearQuarter",
"MonthNumber",
"MonthName",
"MonthShortName",
"Year" * 100 + "MonthNumber" AS "YearMonthNumber",
CONCAT("Year", '-', "MonthShortNameLowerCase") AS "YearMonth",
CONCAT("MonthShortNameLowerCase", ' ', "Year") AS "MonthYear",
"WeekNumber",
EXTRACT(ISOYEAR FROM "Date")::int * 100 + "WeekNumber" as "YearWeek",
"StartOfWeek",
"LastDayOfWeek",
"DayOfWeek",
"DayOfWeekName",
"DayOfMonth",
EXTRACT(DOY FROM "Date")::int as "DayOfYear",
"StartOfYear",
("StartOfYear" + interval '1 year' - interval '1 day')::date as "EndOfYear",
"StartOfQuarter",
("StartOfQuarter" + interval '3 months' - interval '1 day')::date as "EndOfQuarter",
"StartOfMonth",
("StartOfMonth" + interval '1 month' - interval '1 day')::date as "EndOfMonth",
CONCAT(TO_CHAR("DayOfMonth", 'fm00'), '.', TO_CHAR("MonthNumber", 'fm00')) AS "DayMonth",
CONCAT(
    CONCAT(TO_CHAR(EXTRACT(DAY FROM "StartOfWeek"), 'fm00'), '.', TO_CHAR(EXTRACT(MONTH FROM "StartOfWeek"), 'fm00')), 
    '-', 
    CONCAT(TO_CHAR(EXTRACT(DAY FROM "LastDayOfWeek"), 'fm00'), '.', TO_CHAR(EXTRACT(MONTH FROM "LastDayOfWeek"), 'fm00'))
) AS "WeekPeriod",
CASE 
    WHEN "Date" = now()::date THEN 'Сегодня' ELSE "Date"::text
END AS "CurrentDate",
CASE 
    WHEN "MonthNumber" = EXTRACT(MONTH FROM now()::date) THEN 'Текущий месяц' ELSE "MonthShortName"
END AS "CurrentMonth",
CASE 
    WHEN "QuarterNumber" = EXTRACT(QUARTER FROM now()::date) THEN 'Текущий квартал' ELSE "QuarterNumber"::text
END AS "CurrentQuarter",
CASE 
    WHEN "Year" = EXTRACT(YEAR FROM now()::date) THEN 'Текущий год' ELSE "Year"::text
END AS "CurrentYear"
FROM
(
	SELECT *,
	("StartOfWeek" + interval '6 days')::date as "LastDayOfWeek",
	CASE 
	    WHEN "MonthNumber" = 1 THEN 'Январь'
	    WHEN "MonthNumber" = 2 THEN 'Февраль'
	    WHEN "MonthNumber" = 3 THEN 'Март'
	    WHEN "MonthNumber" = 4 THEN 'Апрель'
	    WHEN "MonthNumber" = 5 THEN 'Май'
	    WHEN "MonthNumber" = 6 THEN 'Июнь'
	    WHEN "MonthNumber" = 7 THEN 'Июль'
	    WHEN "MonthNumber" = 8 THEN 'Август'
	    WHEN "MonthNumber" = 9 THEN 'Сентябрь'
	    WHEN "MonthNumber" = 10 THEN 'Октябрь'
	    WHEN "MonthNumber" = 11 THEN 'Ноябрь'
	    WHEN "MonthNumber" = 12 THEN 'Декабрь'
	END AS "MonthName",
	CASE 
	    WHEN "MonthNumber" = 1 THEN 'Янв'
	    WHEN "MonthNumber" = 2 THEN 'Фев'
	    WHEN "MonthNumber" = 3 THEN 'Мар'
	    WHEN "MonthNumber" = 4 THEN 'Апр'
	    WHEN "MonthNumber" = 5 THEN 'Май'
	    WHEN "MonthNumber" = 6 THEN 'Июн'
	    WHEN "MonthNumber" = 7 THEN 'Июл'
	    WHEN "MonthNumber" = 8 THEN 'Авг'
	    WHEN "MonthNumber" = 9 THEN 'Сен'
	    WHEN "MonthNumber" = 10 THEN 'Окт'
	    WHEN "MonthNumber" = 11 THEN 'Ноя'
	    WHEN "MonthNumber" = 12 THEN 'Дек'
	END AS "MonthShortName",
	CASE 
	    WHEN "MonthNumber" = 1 THEN 'янв'
	    WHEN "MonthNumber" = 2 THEN 'фев'
	    WHEN "MonthNumber" = 3 THEN 'мар'
	    WHEN "MonthNumber" = 4 THEN 'апр'
	    WHEN "MonthNumber" = 5 THEN 'май'
	    WHEN "MonthNumber" = 6 THEN 'июн'
	    WHEN "MonthNumber" = 7 THEN 'июл'
	    WHEN "MonthNumber" = 8 THEN 'авг'
	    WHEN "MonthNumber" = 9 THEN 'сен'
	    WHEN "MonthNumber" = 10 THEN 'окт'
	    WHEN "MonthNumber" = 11 THEN 'ноя'
	    WHEN "MonthNumber" = 12 THEN 'дек'
	END AS "MonthShortNameLowerCase",
	CASE
	    WHEN "DayOfWeek" = 1 THEN 'Пн'
	    WHEN "DayOfWeek" = 2 THEN 'Вт'
	    WHEN "DayOfWeek" = 3 THEN 'Ср'
	    WHEN "DayOfWeek" = 4 THEN 'Чт'
	    WHEN "DayOfWeek" = 5 THEN 'Пт'
	    WHEN "DayOfWeek" = 6 THEN 'Сб'
	    WHEN "DayOfWeek" = 7 THEN 'Вс'
	END AS "DayOfWeekName"
	FROM
	(
		SELECT *,
		EXTRACT(YEAR FROM "Date")::int AS "Year",
		EXTRACT(QUARTER FROM "Date")::int as "QuarterNumber",
		EXTRACT(MONTH FROM "Date")::int as "MonthNumber",
		EXTRACT(WEEK FROM "Date")::int as "WeekNumber",
		EXTRACT(ISODOW FROM "Date")::int as "DayOfWeek",
		EXTRACT(DAY FROM "Date")::int as "DayOfMonth",
		date_trunc('week', "Date")::date as "StartOfWeek",
		date_trunc('year', "Date")::date as "StartOfYear",
		date_trunc('quarter', "Date")::date as "StartOfQuarter",
		date_trunc('month', "Date")::date as "StartOfMonth"
		FROM
		(
			SELECT "Date"::date
			FROM generate_series((<startDate>)::timestamp, (<endDate>)::timestamp, interval '1 day') AS "Date"
		) AS "Calendar1"
	) AS "Calendar2"
) AS "Calendar3"